@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KITINERARY_TRAINTRIP_H
@@ -45,6 +45,14 @@ class KITINERARY_EXPORT TrainTrip
     KITINERARY_PROPERTY(QString, trainNumber, setTrainNumber)
     KITINERARY_PROPERTY(KItinerary::Organization, provider, setProvider)
 
+    // KDE extensions
+    /** The scheduled day of departure.
+     *  This is needed for unbound train reservations where we don't know the
+     *  exact travel details yet.
+     *  @see Flight
+     */
+    KITINERARY_PROPERTY(QDate, departureDay, setDepartureDay)
+
 private:
     QExplicitlySharedDataPointer<TrainTripPrivate> d;
 };
