@@ -44,7 +44,7 @@ Extractor::Extractor()
     : d(new ExtractorPrivate)
 {
 }
-Extractor::Extractor(Extractor &&) = default;
+Extractor::Extractor(Extractor &&) noexcept = default;
 Extractor::~Extractor() = default;
 
 bool Extractor::load(const QJsonObject &obj, const QString &baseDir)
@@ -60,7 +60,8 @@ bool Extractor::load(const QJsonObject &obj, const QString &baseDir)
         d->m_type = ICal;
     }
 
-    for (const auto &filterValue : obj.value(QLatin1String("filter")).toArray()) {
+    const auto filterArray = obj.value(QLatin1String("filter")).toArray();
+    for (const auto &filterValue : filterArray) {
         ExtractorFilter f;
         if (!f.load(filterValue.toObject())) {
             return false;
