@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "jsonld.h"
@@ -24,6 +24,8 @@
 #include <QJSEngine>
 #include <QJsonArray>
 #include <QLocale>
+#include <QRegularExpression>
+#include <QUrl>
 
 using namespace KItinerary;
 
@@ -60,6 +62,32 @@ QDateTime JsApi::JsonLd::toDateTime(const QString &dtStr, const QString &format,
         dt = locale.toDateTime(dtStrFixed, format);
     }
 
+    // try even harder for "MMM" month format
+    // in the de_DE locale we encounter sometimes almost arbitrary abbreviations for month
+    // names (eg. Mrz, Mär for März). So try to identify those and replace them with what QLocale
+    // expects
+    if (!dt.isValid() && format.contains(QLatin1String("MMM"))) {
+        auto dtStrFixed = dtStr;
+        for (int i = 1; i <= 12; ++i) {
+            const auto monthName = locale.monthName(i, QLocale::LongFormat);
+            const auto beginIdx = dtStr.indexOf(monthName.at(0));
+            if (beginIdx < 0) {
+                continue;
+            }
+            auto endIdx = beginIdx;
+            for (auto nameIdx = 0; endIdx < dtStr.size() && nameIdx < monthName.size(); ++nameIdx) {
+                if (dtStr.at(endIdx).toCaseFolded() == monthName.at(nameIdx).toCaseFolded()) {
+                    ++endIdx;
+                }
+            }
+            if (endIdx - beginIdx >= 3) {
+                dtStrFixed = dtStrFixed.replace(beginIdx, endIdx - beginIdx, locale.monthName(i, QLocale::ShortFormat));
+                break;
+            }
+        }
+        dt = locale.toDateTime(dtStrFixed, format);
+    }
+
     if (!dt.isValid()) {
         return dt;
     }
@@ -108,6 +136,28 @@ QJSValue JsApi::JsonLd::clone(const QJSValue& v) const
     return m_engine->toScriptValue(v.toVariant());
 }
 
+QJSValue JsApi::JsonLd::toGeoCoordinates(const QString &mapUrl)
+{
+    QUrl url(mapUrl);
+    if (url.host().contains(QLatin1String("google"))) {
+        QRegularExpression regExp(QStringLiteral("[/=](-?\\d+\\.\\d+),(-?\\d+\\.\\d+)"));
+        auto match = regExp.match(url.path());
+        if (!match.hasMatch()) {
+            match = regExp.match(url.query());
+        }
+
+        if (match.hasMatch()) {
+            auto geo = m_engine->newObject();
+            geo.setProperty(QStringLiteral("@type"), QStringLiteral("GeoCoordinates"));
+            geo.setProperty(QStringLiteral("latitude"), match.capturedRef(1).toDouble());
+            geo.setProperty(QStringLiteral("longitude"), match.capturedRef(2).toDouble());
+            return geo;
+        }
+    }
+
+    return {};
+}
+
 void JsApi::JsonLd::setContextDate(const QDateTime& dt)
 {
     m_contextDate = dt;
